@@ -978,8 +978,9 @@ $recalculateish1 =
 # name of daylight factor file
 ); #
 
-
-
+$skip1 = "if ( ($$translate[$counterzone][2][0] > 2) or ($$translate[$counterzone][2][0] < 8 ) )"; 
+# THIS IS AN EXAMPLE OF CONDITION TO SKIP SOME TESTS. THIS IS A CONDITION WRITTEN IN PERL AND CAN BE AS COMPLEX AS YOU WANT.
+# IT WILL BE EVALED BY THE PROGRAM TO SKIP AN INSTANCE IF CONDITION YOU HAVE SPECIFIED IS MET.
 
 
 ############################## HERE FOLLOWS THE DESCRIPTION OF MORPHING PHASE NUMBER 2. ##########################
@@ -1042,6 +1043,10 @@ $translate2 =  [ [  #####  @applytype1 = (["translation", "file_name.geo", "targ
 [unused] # OPTIONAL. FIFTH SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE.
 ];
 
+$skip2 = ""; 
+# THIS IS AN EXAMPLE OF CONDITION TO SKIP SOME TESTS. THIS IS A CONDITION WRITTEN IN PERL AND CAN BE AS COMPLEX AS YOU WANT.
+# IT WILL BE EVALED BY THE PROGRAM TO SKIP AN INSTANCE IF CONDITION YOU HAVE SPECIFIED IS MET. NONE, IN THIS CASE
+
 ### … AND SO ON FOR ALL THE OTHER VARIABLES AND SEARCH CYCLE NUMBERS. ALL ONE HAVE TO DO IS CHANGE THE NUMBER OF THE VARIABLES FOR EACH CYCLE. (EXAMPLE: @applytype1 FOR CYCLE 1, @applytype2 FOR CYCLE TO, AND SO ON.) AND IF IN A CERTAIN CYCLE A VARIABLE IS NOT USED, IT HAS NOT TO BE SPECIFIED. JUST FEW VARIABLE ARE MANDATORY FOR EACH CYCLE: $stepsvar, @applytype and $general_variables . THE ORDER OF THE CYCLES TO BE FOLLOWED IS SPECIFIED BY @varnumbers .
 
 1; # <- LEAVE THIS “1! HERE.
